/*
  -----------------Note----------------------
  Date: 02-04-2020
  Project Name: Expert Control Box
  Goal: Testing data Package Radio Module 
  Author: Khang Nguyen          
*/
#include <SPI.h>
#include <nRF24L01.h>
#include <RF24.h>
RF24 radio(9, 10); // CE, CSN      
   
const byte address[6] = "00001";


const int L_button = 7;
const int R_button = 6;

const int Knob = A0 ;
const int LED2 = 3 ;
const int LED1 = 5 ;  

int L_button_state = 0;
int R_button_state = 0;

int forward = 0 ;
int backward = 0;

int K_knob_value = 0 ;
long P_Knob_Value = 0 ;

unsigned long lastReceiveTime = 0;
unsigned long currentTime = 0;


struct Data_Package
{
  byte L_Switch;
  byte R_Switch;
  byte Knob_Value;
};

Data_Package data;


void setup()
{
  Serial.begin(9600);

     
  pinMode(L_button, INPUT);
  pinMode(R_button, INPUT);

  pinMode(LED1 , OUTPUT);
  pinMode(LED2 , OUTPUT);

  Tranmitter_Setup();

  resetData();
}

void loop()
{
    L_button_state = digitalRead(L_button);
    R_button_state = digitalRead(R_button);
    K_knob_value = analogRead(Knob);
    P_Knob_Value = map(K_knob_value,1023,0,9,255);

    data.Knob_Value = K_knob_value;
   
    Serial.print("Knob Value: ");Serial.println(P_Knob_Value);

    //Knob_Function();

    if(R_button_state == HIGH)
    {
      digitalWrite(LED1,HIGH);
      data.R_Switch=0;
    }
      else
    {
      digitalWrite(LED1,LOW);
      data.R_Switch=1;
      }
     
    if(L_button_state == HIGH)
    {
      digitalWrite(LED2,HIGH);
      data.L_Switch=0;
     }
      else
     {
        digitalWrite(LED2,LOW);
        data.L_Switch=1;
     }
     
    radio.write(&data, sizeof(Data_Package));

}

    //----------Radio---------//

int Tranmitter_Setup()
{
  radio.begin();
  radio.openWritingPipe(address);
  radio.setAutoAck(false);
  radio.setDataRate(RF24_250KBPS);

}

//===========Knob_Function============//

void Knob_Function()
{
  if ( P_Knob_Value > 10)
  {
 //====================Left_Button====================//
   if (L_button_state == LOW)
   {
      analogWrite(LED1,P_Knob_Value );
      Serial.println("Left button press!");
    }
   
   if (L_button_state == HIGH)
   {
    analogWrite(LED1,0);  
    Serial.println("Left button release!");
   }
//====================Right_Button====================//
   if (R_button_state == LOW)
   {
      analogWrite(LED2,P_Knob_Value );
      Serial.println("Right button press!");
    }
   
   if (R_button_state == HIGH)
   {
      analogWrite(LED2,0);
    Serial.println("Right button release!");
   }
  }
}
//====================Data_Package====================//
void resetData()
{
  data.L_Switch = 1;
  data.R_Switch = 1;
  data.Knob_Value = 0;
}
